package com.mile.v4_navigation_engine.Navigation.service

import android.app.Service
import android.content.Intent
import android.os.IBinder
import android.os.Looper
import android.util.Log
import android.widget.Toast
import com.google.android.gms.location.*


/**
 * Starts location updates on background and publish LocationUpdateEvent upon
 * each new location result.
 */
class LocationUpdateService : Service() {

    companion object {
        //region data
        private const val UPDATE_INTERVAL_IN_MILLISECONDS: Long = 3000
        const val MY_SERVICE = "LOCATION_UPDATE_SERVICE"
        const val REFRESH_DATA_INTENT = "REFRESH_DATA_INTENT"
    }

    private var mFusedLocationClient: FusedLocationProviderClient? = null
    private var locationRequest: LocationRequest? = null
    private val locationSettingsRequest: LocationSettingsRequest? = null

    //endregion
    //onCreate
    override fun onCreate() {
        super.onCreate()
        initData()
    }


    override fun onDestroy() {
        mFusedLocationClient!!.removeLocationUpdates(locationCallback)
        super.onDestroy()
    }

    //Location Callback
    private val locationCallback: LocationCallback = object : LocationCallback() {
        override fun onLocationResult(locationResult: LocationResult) {
            super.onLocationResult(locationResult)
            val currentLocation = locationResult.lastLocation
            Log.d("Locations", currentLocation.latitude.toString() + "," + currentLocation.longitude)
            var intent = Intent(REFRESH_DATA_INTENT)
            intent.putExtra("polyline_location_service", locationResult.lastLocation)
            sendBroadcast(intent);
            //Share/Publish Location
        }
    }

    override fun onStartCommand(intent: Intent, flags: Int, startId: Int): Int {
        prepareForegroundNotification()
        startLocationUpdates()
        return START_STICKY
    }

    private fun startLocationUpdates() {
        mFusedLocationClient!!.requestLocationUpdates(locationRequest, locationCallback, Looper.myLooper())
    }

    private fun prepareForegroundNotification() {
        /*val text = "Hello toast!"
        val duration = Toast.LENGTH_SHORT

        val toast = Toast.makeText(applicationContext, text, duration)
        toast.show()*/
    }

    override fun onBind(intent: Intent): IBinder? {
        return null
    }

    private fun initData() {
        locationRequest = LocationRequest.create()
        locationRequest!!.setInterval(UPDATE_INTERVAL_IN_MILLISECONDS)
        locationRequest!!.setPriority(LocationRequest.PRIORITY_HIGH_ACCURACY)
        mFusedLocationClient = LocationServices.getFusedLocationProviderClient(applicationContext)
    }
}